---
title: previewing files
description: how rovr's file preview panel works.
---

`rovr` includes a powerful preview sidebar that can display the contents of various filetypes.

### text files

plain text files are displayed in a text area with syntax highlighting. the language is determined by the file extension. `rovr` supports a wide range of languages.

### bat plugin

if you have [`bat`](/rovr/features/plugins#bat) installed and enabled in the `rovr` config, it will be used to display text files with syntax highlighting for much more languages and theming.

### images

`rovr` can display images directly in the terminal. refer to the [image previews](/rovr/features/image-previews) guide for more details on terminal compatibility and configuration.

### folders

when a folder is selected, the preview panel will show a list of the files and folders inside it, allowing you to see the contents without navigating into it.

### archives

for archive files (like `.zip`, `.tar.gz`, etc.), `rovr` will display a list of the files and folders contained within the archive.
